@@ -1,3 +1,4 @@
+from contextlib import suppress
 import boto3
 from datetime import datetime
 from .settings import settings
@@ -7,8 +8,9 @@ region = settings.AWS_REGION
 bucket_name = settings.S3_BUCKET_NAME
 dynamo_state_table_name = settings.DYNAMODB_STATE_TABLE_NAME
 
-dynamodb = boto3.resource('dynamodb', endpoint_url=f"https://dynamodb.{region}.amazonaws.com")
-s3 = boto3.resource('s3', endpoint_url=f"https://s3.{region}.amazonaws.com")
+with suppress(Exception):  # not gonna need this on local
+    dynamodb = boto3.resource('dynamodb', region_name=region)
+    s3 = boto3.resource('s3', region_name=region)
 
 
 def _upload_metadata(data_type, source_company, item):
