@@ -1,3 +1,4 @@
+from contextlib import suppress
 import boto3
 from datetime import datetime
 import hashlib
@@ -6,8 +7,10 @@ from botocore.exceptions import ClientError
 from .settings import settings
 
 region = settings.AWS_REGION
-dynamodb = boto3.resource('dynamodb', endpoint_url=f"https://dynamodb.{region}.amazonaws.com")
-s3 = boto3.resource('s3', endpoint_url=f"https://s3.{region}.amazonaws.com")
+
+with suppress(Exception):  # not gonna need this on local
+    dynamodb = boto3.resource('dynamodb', region_name=region)
+    s3 = boto3.resource('s3', region_name=region)
 
 
 def hashing(s):
